""":synopsis: Core package of shellstreaming

.. moduleauthor:: Sho Nakatani <lay.sakura@gmail.com>
"""

__versioninfo__ = (0, 0, 5)
__version__     = '.'.join(map(str, __versioninfo__))
__author__      = 'Sho Nakatani'
__email__       = 'lay.sakura@gmail.com'
__copyright__   = 'Copyright 2013, Sho Nakatani'
